.. sPickle documentation master file, created by
   sphinx-quickstart on Wed Jun 22 14:05:04 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to sPickle's documentation!
===================================

Contents:

.. toctree::

   sPickle

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

